@@ -3,6 +3,6 @@ from yonde.exceptions import *
 from yonde.extractors import *
 from yonde.images import *
 from yonde.main_class import *
-from yonde.printer import *
+from yonde.color import *
 from yonde.session import *
 from yonde.main import Yonde
